@@ -233,6 +233,7 @@ static PlaylistTypes dual_types[] = {
 	PLAYLIST_TYPE2 ("application/x-php", NULL, NULL),
 	PLAYLIST_TYPE2 ("audio/x-ms-asx", totem_pl_parser_add_asx, totem_pl_parser_is_asx),
 	PLAYLIST_TYPE2 ("video/x-ms-asf", totem_pl_parser_add_asf, totem_pl_parser_is_asf),
+	PLAYLIST_TYPE2 ("application/vnd.ms-asf", totem_pl_parser_add_asf, totem_pl_parser_is_asf),
 	PLAYLIST_TYPE2 ("video/x-ms-wmv", totem_pl_parser_add_asf, totem_pl_parser_is_asf),
 	PLAYLIST_TYPE2 ("audio/x-ms-wma", totem_pl_parser_add_asf, totem_pl_parser_is_asf),
 	PLAYLIST_TYPE2 ("video/quicktime", totem_pl_parser_add_quicktime, totem_pl_parser_is_quicktime),
@@ -1556,6 +1557,8 @@ totem_pl_parser_scheme_is_ignored (TotemPlParser *parser, GFile *uri)
 	g_mutex_lock (&parser->priv->ignore_mutex);
 
 	scheme = g_file_get_uri_scheme (uri);
+	if (!scheme)
+		return TRUE;
 	ret = GPOINTER_TO_INT (g_hash_table_lookup (parser->priv->ignore_schemes, scheme));
 	g_free (scheme);
 
@@ -2263,7 +2266,7 @@ totem_pl_parser_parse_duration (const char *duration, gboolean debug)
 
 	/* Formats used by both ASX and RAM files */
 	if (sscanf (duration, "%d:%d:%d.%d", &hours, &minutes, &seconds, &fractions) == 4) {
-		gint64 ret = hours * 3600 + minutes * 60 + seconds;
+		gint64 ret = (gint64) hours * 3600 + (gint64) minutes * 60 + seconds;
 		if (ret == 0 && fractions > 0) {
 			D(g_print ("Used 00:00:00.00 format, with fractions rounding\n"));
 			ret = 1;
@@ -2274,7 +2277,7 @@ totem_pl_parser_parse_duration (const char *duration, gboolean debug)
 	}
 	if (sscanf (duration, "%d:%d:%d", &hours, &minutes, &seconds) == 3) {
 		D(g_print ("Used 00:00:00 format\n"));
-		return hours * 3600 + minutes * 60 + seconds;
+		return (gint64) hours * 3600 + (gint64) minutes * 60 + seconds;
 	}
 	if (sscanf (duration, "%d:%d.%d", &minutes, &seconds, &fractions) == 3) {
 		gint64 ret = minutes * 60 + seconds;
@@ -2288,16 +2291,16 @@ totem_pl_parser_parse_duration (const char *duration, gboolean debug)
 	}
 	if (sscanf (duration, "%d:%d", &minutes, &seconds) == 2) {
 		D(g_print ("Used 00:00 format\n"));
-		return minutes * 60 + seconds;
+		return (gint64) minutes * 60 + seconds;
 	}
 	if (sscanf (duration, "%d.%d", &minutes, &seconds) == 2) {
 		D(g_print ("Used broken float format (00.00)\n"));
-		return minutes * 60 + seconds;
+		return (gint64) minutes * 60 + seconds;
 	}
 	/* YouTube format */
 	if (sscanf (duration, "%dm%ds", &minutes, &seconds) == 2) {
 		D(g_print ("Used YouTube format\n"));
-		return minutes * 60 + seconds;
+		return (gint64) minutes * 60 + seconds;
 	}
 	/* PLS files format */
 	if (sscanf (duration, "%d", &seconds) == 1) {
